==> haskell-charset-0.3.8-13-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-charset.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 charset
version:              0.3.8
visibility:           public
id:                   charset-0.3.8-jhPSWPHz5v2DXq1eU9KQJ
key:                  charset-0.3.8-jhPSWPHz5v2DXq1eU9KQJ
license:              BSD-3-Clause
copyright:            (c) Edward Kmett 2010-2012
maintainer:           ekmett@gmail.com
author:               Edward Kmett
stability:            Experimental
homepage:             http://github.com/ekmett/charset
synopsis:
    Fast unicode character sets based on complemented PATRICIA tries

description:
    Fast unicode character sets based on complemented PATRICIA tries.

category:             Data
abi:                  0eb3ce864dd5c8633119d92fd576ebde
exposed:              True
exposed-modules:
    Data.CharSet Data.CharSet.ByteSet Data.CharSet.Common
    Data.CharSet.Posix Data.CharSet.Posix.Ascii
    Data.CharSet.Posix.Unicode Data.CharSet.Unicode
    Data.CharSet.Unicode.Block Data.CharSet.Unicode.Category

import-dirs:          /usr/lib/ghc-8.10.4/site-local/charset-0.3.8
library-dirs:         /usr/lib/ghc-8.10.4/site-local/charset-0.3.8
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.4/charset-0.3.8
hs-libraries:         HScharset-0.3.8-jhPSWPHz5v2DXq1eU9KQJ
depends:
    array-0.5.4.0 base-4.14.1.0 bytestring-0.10.12.0 containers-0.6.2.1
    unordered-containers-0.2.13.0-GpKX90RmBie7xFEkTgVtxL

haddock-interfaces:   /usr/share/doc/haskell-charset/html/charset.haddock
haddock-html:         /usr/share/doc/haskell-charset/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-charset-0.3.8-14-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-charset.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 charset
version:              0.3.8
visibility:           public
id:                   charset-0.3.8-HpXvOOPnptCEBtTv3KwfxL
key:                  charset-0.3.8-HpXvOOPnptCEBtTv3KwfxL
license:              BSD-3-Clause
copyright:            (c) Edward Kmett 2010-2012
maintainer:           ekmett@gmail.com
author:               Edward Kmett
stability:            Experimental
homepage:             http://github.com/ekmett/charset
synopsis:
    Fast unicode character sets based on complemented PATRICIA tries

description:
    Fast unicode character sets based on complemented PATRICIA tries.

category:             Data
abi:                  1bf34a64f6e47113b3cd3b5215432e37
exposed:              True
exposed-modules:
    Data.CharSet Data.CharSet.ByteSet Data.CharSet.Common
    Data.CharSet.Posix Data.CharSet.Posix.Ascii
    Data.CharSet.Posix.Unicode Data.CharSet.Unicode
    Data.CharSet.Unicode.Block Data.CharSet.Unicode.Category

import-dirs:          /usr/lib/ghc-8.10.4/site-local/charset-0.3.8
library-dirs:         /usr/lib/ghc-8.10.4/site-local/charset-0.3.8
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.4/charset-0.3.8
hs-libraries:         HScharset-0.3.8-HpXvOOPnptCEBtTv3KwfxL
depends:
    array-0.5.4.0 base-4.14.1.0 bytestring-0.10.12.0 containers-0.6.2.1
    unordered-containers-0.2.13.0-3zq6q89i05VC2WIEWnQHAq

haddock-interfaces:   /usr/share/doc/haskell-charset/html/charset.haddock
haddock-html:         /usr/share/doc/haskell-charset/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
